@@ -3,3 +3,7 @@
 
 class InvalidGPXError(Exception):
     """GPX is invalid."""
+
+
+class ParseError(Exception):
+    """No element to parse."""
